==> create-lumapps-extension-0.5.0.tgz: package/template-widget-extension/src/config.js <==
/**
 *  Create-LumApps-Widget config file
 *  update the following to fit your needs
 */

export const useGlobalSettings = true;

/**
 * The ids of your partner and extension
 */
const partnerId = '';
const extensionId = '';

const description = {
    en: 'SampleWidgetTypescript',
};

const name = {
    en: 'SampleWidgetTypescript',
};

const icon = {
    en:
        'https://lh3.googleusercontent.com/-6F_iwel8KGY/WD8MdGS0PkI/AAAAAAAAGDI/KaqvKtZCK_AsdK6BcKp6Cy1MpwoEWCUvgCKgB/s400/logo.png', // a working link to your widget icon
};

/**
 * Whether the extension requires an oauth application
 */
const oauth = false;

/**
 * The documentation's url of the extension.
 */
const links = {
    documentation: null,
}

/**
 * The components available for your extensions
 * 'content' : For the Widget content itself (required)
 * 'settings' : For your widget settings
 * 'globalSettings' : For global settings used by platform admin.
 */
const components = ['content', 'settings', 'global_settings'];

// Whether the extension is public or not in the marketplace.
const isPublic = true;

/**
 * The list of authorized customer ids.
 *
 * If your extension is not public only these customers will see and
 * will be able to install this extensions.
 */
const whitelist = [];

// do not change the following unless you know what you are doing
const config = {
    partnerId,
    extensionId,
    name,
    description,
    icon,
    oauth,
    links,
    components,
    isPublic,
    public: isPublic,
    whitelist,
    category: 'widget',
};

if (!useGlobalSettings) {
    config.components.pop();
}

export default config;

==> create-lumapps-extension-1.0.1.tgz: package/template-widget-extension/src/config.js <==
/**
 *  Create-LumApps-Widget config file
 *  update the following to fit your needs
 */

/**
 * The ids of your partner and extension
 */
const partnerId = {
    beta: '',
    production: '',
};

const extensionId = {
    beta: '',
    production: '',
};

const description = {
    en: 'SampleWidgetTypescript',
};

const name = {
    en: 'SampleWidgetTypescript',
};

const icon = {
    en:
        'https://lh3.googleusercontent.com/-6F_iwel8KGY/WD8MdGS0PkI/AAAAAAAAGDI/KaqvKtZCK_AsdK6BcKp6Cy1MpwoEWCUvgCKgB/s400/logo.png', // a working link to your widget icon
};

const oauth = false;

/**
 * Define the availability of your extension :
 * - open : available for everyone
 * - marketplace : the customer need to have access to the marketplace
 */

const availability = 'marketplace';

/**
 * Define if your extension needs to connect to external service through an application declare on provider side.
 *
 * Uncomment the following block to declare application usage for your extension.
 * Do not forget to add the application attribute in the config object.
 */
/*const application = {
    providerType: '',
};*/

/**
 * The documentation's url of the extension.
 */
const links = {
    documentation: null,
};

/**
 * The components available for your extensions
 * 'content' : For the Widget content itself (required)
 * 'settings' : For your widget settings
 * 'globalSettings' : For global settings used by platform admin.
 */
const components = ['content', 'settings', 'global_settings'];

// Whether the extension is public or not in the marketplace.
const isPublic = true;

/**
 * The list of authorized customer ids.
 *
 * If your extension is not public only these customers will see and
 * will be able to install this extensions.
 */
const whitelist = [];

// do not change the following unless you know what you are doing
const config = {
    availability,
    category: 'widget',
    components,
    description,
    extensionId,
    icon,
    links,
    name,
    oauth,
    partnerId,
    public: isPublic,
    whitelist,
};

export default config;
